#[non_exhaustive]
#[repr(u32)]
pub enum Type { None = 0, Photo = 1, Video = 2, Game = 3, }
Available on crate feature wayland and Linux only.
possible content types

These values describe the available content types for a surface.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None = 0

no content type applies

The content type none means that either the application has no data about the content type, or that the content doesn’t fit into one of the other categories.



Photo = 1

photo content type

The content type photo describes content derived from digital still pictures and may be presented with minimal processing.



Video = 2

video content type

The content type video describes a video or animation and may be presented with more accurate timing to avoid stutter. Where scaling is needed, scaling methods more appropriate for video may be used.



Game = 3

game content type

The content type game describes a running game. Its content may be presented with reduced latency.