Struct WpContentTypeV1
pub struct WpContentTypeV1 { /* private fields */ }wayland and Linux only.Expand description
content type object for a surface
The content type object allows the compositor to optimize for the kind of content shown on the surface. A compositor may for example use it to set relevant drm properties like “content type”.
The client may request to switch to another content type at any time. When the associated surface gets destroyed, this object becomes inert and the client should destroy it.
This interface has no events.
Implementations
impl WpContentTypeV1
impl WpContentTypeV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the content type object
Switch back to not specifying the content type of this surface. This is equivalent to setting the content type to none, including double buffering semantics. See set_content_type for details.
pub fn set_content_type(&self, content_type: Type)
pub fn set_content_type(&self, content_type: Type)
specify the content type
Set the surface content type. This informs the compositor that the client believes it is displaying buffers matching this content type.
This is purely a hint for the compositor, which can be used to adjust its behavior or hardware settings to fit the presented content best.
The content type is double-buffered state, see wl_surface.commit for details.